class CParameter{
 public:
  // max. number of particles in an ensemble
  int AMAX;
  // filename containing phase space points
  string infilename;
  // Boosting (blastwave) parameters
  double ytmax;
  double etamax;
  // Binning info for balance function
  double delq;
  double delrap;
  int nbins;
  // Results printed to files in this directory
  string resultsdirname;
  // Acceptances
  bool na49acceptance,staracceptance,acceptall;
  void ReadPars(string filename);
  CParameter(string filename);
};

CParameter::CParameter(string filename){
  // Set default values
  AMAX=70;
  ytmax=0.9;
  etamax=1.0;;
  nbins=20;
  delq=20.0;
  delrap=0.04;
  infilename="../canonical/decay_results_Tkin120_Tchem175_Vchem64_allresonances.tmp";
  resultsdirname="results";
  ReadPars(filename);
}

void CParameter::ReadPars(string filename){
  ifstream infile;
  string key;
  string value;
  char dummy[120];
  infile.open(filename.c_str());
  while(infile >> key >> value){
    infile.getline(dummy,100);
    if(key.c_str()[0]!='#'){
      if(key=="ytmax") ytmax=atof(value.c_str());
      else if(key=="etamax") etamax=atof(value.c_str());
      else if(key=="infilename") infilename=value;
      else if(key=="AMAX") AMAX=atoi(value.c_str());
      else if(key=="nbins") nbins=atoi(value.c_str());
      else if(key=="delq") delq=atof(value.c_str());
      else if(key=="delrap") delrap=atof(value.c_str());
      else if(key=="resultsdirname") resultsdirname=value;
      else if(key=="na49acceptance") na49acceptance=atoi(value.c_str());
      else if(key=="staracceptance") staracceptance=atoi(value.c_str());
      else if(key=="acceptall") acceptall=atoi(value.c_str());
      else cout << "Parameter Keyword " << key << " not recognized" << endl;
    }
  }
  cout << "____ PARAMETERS____" << endl;
  cout << "AMAX=" << AMAX << endl;
  cout << "ytmax=" << ytmax << ", etamax=" << etamax << endl;
  cout << "infilename=" << infilename << endl;
  cout << "nbins=" << nbins << ", delq=" 
       << delq << " MeV/c, delrap=" << delrap << endl;
  cout << "resultsdirname=" << resultsdirname << endl;
  cout << "na49acceptance=" << na49acceptance
       << ", staracceptance=" << staracceptance
       << ", acceptall=" << acceptall << endl;

  infile.close();
}

