#ifndef _PARTITION_H_INCLUDED_
#define _PARTITION_H_INCLUDED_

//====================================================================
//     PARTITION FUNCTION CALCULATOR
//
//     for ensembles with three elementary charge types: isospin,
//     baryon number, strangeness
//
//     26 Oct 2002 - 21 Nov 2002
//     S. Petriconi
//====================================================================

using namespace std;

class XOutOfRange
{
	public: XOutOfRange() {};
};

class XUnexpectedFileError
{
	public: XUnexpectedFileError() {};
};

//---------------------------------------------------------------------

class Zmap : public map<charge, double>
{
public:
   Zmap() {};
   bool contribute(const charge& Q, double value);
   bool contribute_nosymm(const charge &Q, double value);
   double get_Z(const charge& Q) const;
};
		
//---------------------------------------------------------------------

class partition_function
{
public:
	partition_function(const particle_zoo& particles,
		int maxA);
	partition_function(particle_zoo &particles, string filename);
  	~partition_function();

	double getZ(int A, const charge& Q) const;
	void   writeToFile(string filename) const;
	void calculate_Aprob(charge& Q,double *Aprob);
	int	 	    its_max_A;
private:

	void do_computation();

	int read_headers(particle_zoo &zoo); // read hdrs and return maxA
	void read_data();

        struct charge_range { charge lower; charge upper; };

	vector<Zmap>        its_Z_map_array;
	vector<charge_range>its_charge_boundaries;
	const particle_zoo& its_particle_zoo;

	ifstream	    its_inputfilestream;
};

#endif // _PARTITION_H_INCLUDED_
